#
# File: $Id: template_ruleset.py,v 1.2 2005/04/04 00:45:40 gnn Exp $
#
# Author: David Wheeler
#         George V. Neville-Neil (local modifications)
#
# Description: A template for other rulesets to be created for
# flawfinder.  This file ONLY describes how a ruleset would work and
# does not specify a useful ruleset for use by others.

# When adding a new ruleset you have to tell the system the extensions  that
# are used by your files.  This example handles C and C++.

template_ruleset_extensions = { '.c' : 1, '.h' : 1,
                                '.ec': 1, '.ecp': 1,  # Informix embedded C.
                                '.pgc': 1,            # Postgres embedded C.
                                '.C': 1, '.cpp': 1, '.CPP': 1, # C++
                                '.cxx': 1, '.cc': 1, '.CC' : 1,   # More C++.
                                '.pcc': 1,            # Oracle C++
                                '.hpp': 1, '.H' : 1,  # .h - usually C++.
                                }

template_ruleset = {
  # This is a template for adding new entries (the key is impossible):
  "strcpy" : # Key, this is a string to be found in the file.
     (c_buffer, # Python function to call to process this "Hit"
      4,     # Level of warning where 0 is no risk and 5 is maximum risk
      # Short explanation of the issue
      "Does not check for buffer overflows when copying to destination",
      # Recommendation
      "Consider using strncpy or strlcpy (warning, strncpy is easily misused)",
      "buffer", # category: One of "buffer" (buffer overflow),
                #                  "race" (race condition),
                #                  "tmpfile" (temporary file creation),
                #                  "format" (format string).
                #                  "input" (input validation)
                #                  Use "" if you don't have a better category.
      "",       # URL reference for more information
      {})       # Dictionary of other settings
  }


